@@ -9,6 +9,8 @@ import stat
 
 from contextlib import contextmanager
 from ConfigParser import ConfigParser
+from tempfile import NamedTemporaryFile
+
 
 log = logging.getLogger(__name__)
 
@@ -138,6 +140,7 @@ class Installer(object):
     def uninstall_package(self, with_custom_actions=True):
         raise NotImplementedError()
 
+
 class MsiInstaller(Installer):
     package_extension = 'msi'
     executable_extension = 'exe'
@@ -217,6 +220,7 @@ class RpmInstaller(Installer):
             env['NO_CUSTOM_ACTIONS'] = '1'
         execute_assert_success(['rpm', '-e', self.package_name], env=env)
 
+
 class DebInstaller(Installer):
     package_extension = 'deb'
 
@@ -236,3 +240,46 @@ class DebInstaller(Installer):
         if not with_custom_actions:
             env['NO_CUSTOM_ACTIONS'] = '1'
         execute_assert_success(['dpkg', '-r', self.package_name], env=env)
+
+
+class PkgInstaller(Installer):
+    package_extension = 'pkg.gz'
+
+    def __init__(self, *args, **kwargs):
+        super(PkgInstaller, self).__init__(*args, **kwargs)
+        admin_file_content = '\n'.join(['partial=nocheck',
+                                    'runlevel=nocheck',
+                                    'idepend=nocheck',
+                                    'rdepend=nocheck',
+                                    'setuid=nocheck',
+                                    'action=nocheck',
+                                    'instance=overwrite',
+                                    'basedir=default'])
+        self.admin_file = NamedTemporaryFile(mode='w')
+        self.admin_file.write(admin_file_content)
+        self.admin_file.flush()
+        os.fsync(self.admin_file.fileno())
+
+    def is_product_installed(self):
+        return 0 == execute(["pkginfo", self.package_name]).get_returncode()
+
+    def install_package(self, with_custom_actions=True):
+        response_file = NamedTemporaryFile(mode='w')
+        response_file.write("NO_CUSTOM_ACTIONS={}".format(int(not with_custom_actions)))
+        response_file.flush()
+        os.fsync(response_file.fileno())
+        with prevent_access_to_pypi_servers(), prevent_access_to_gcc():
+            zipped_package_name = self.get_package()
+            unzipped_package_name = zipped_package_name[:-3]
+            execute_assert_success('gunzip -c {} > {}'.format(zipped_package_name, unzipped_package_name), shell=True)
+            execute_assert_success(['pkgadd',
+                                    '-n',
+                                    '-a', self.admin_file.name,
+                                    '-r', response_file.name,
+                                    '-d', unzipped_package_name,
+                                    self.package_name])
+
+    def uninstall_package(self, with_custom_actions=True):
+        # with_custom_actions is actually ignored here. This flag is passed to the installer through the response file.
+        # Luckily, the preremove scripts also gets this info (it's saved somwhere in the os until the removal)
+        execute_assert_success(['pkgrm', '-n', '-a', self.admin_file.name, self.package_name], allowed_return_codes=[0,])
