@@ -2,6 +2,7 @@ from __future__ import print_function
 __import__("pkg_resources").declare_namespace(__name__)
 
 from sys import argv
+import time
 import os
 
 INSTALLDIR = os.path.abspath(os.path.join(os.path.dirname(__file__), #scripts
@@ -11,7 +12,10 @@ INSTALLDIR = os.path.abspath(os.path.join(os.path.dirname(__file__), #scripts
                                           os.path.pardir, #src
                                           os.path.pardir))
 
+from .refactoring import before
+
 def hello(argv=argv):
+    before()
     print('hello world')
 
 def _write_file(name):
@@ -19,10 +23,22 @@ def _write_file(name):
         fd.write(' ')
 
 def post_install(argv=argv):
+    before()
     _write_file('post_install')
 
 def pre_uninstall(argv=argv):
     _write_file(os.path.join(INSTALLDIR, os.path.pardir, 'pre_uninstall'))
 
 def sample(argv=argv):
+    before()
     raw_input('sample, hit enter to exit')
+
+def sleep(argv=argv):
+    before()
+    t0 = time.time()
+    timeout = int(argv[-1])
+    try:
+        time.sleep(timeout)
+    except KeyboardInterrupt:  # windows installer does this
+        timeout = abs(timeout - (time.time() - t0))
+        time.sleep(timeout)
